==> mac-11.08.zip: Source/MAC/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by MAC.rc
//
#define _USING_V110_SDK71_              1
#define IDC_SYSTEM_INFO                 2
#define IDD_MAC_DIALOG                  102
#define IDD_MAKEAPL_DIALOG              103
#define IDR_MAINFRAME                   128
#define IDR_MAIN_MENU                   128
#define IDB_TREE_ICONS                  143
#define IDB_TOOLBAR_FULL                145
#define IDR_STOP_MENU                   145
#define IDD_OPTIONS                     146
#define IDB_TOOLBAR_SMALL               147
#define IDB_MONKEY_WATERMARK            148
#define IDB_OPTIONS_ICONS               149
#define IDD_OPTIONS_OUTPUT              149
#define IDD_OPTIONS_PROCESSING          151
#define IDR_COMPLETION_WAVE             152
#define IDD_FORMAT_PLUGIN_CONFIGURE     154
#define IDD_FORMAT_PLUGIN_INFO          155
#define IDD_APE_INFO                    159
#define IDD_ABOUT                       160
#define IDD_APE_INFO_FORMAT             161
#define IDC_LIST                        1000
#define IDC_BUILD_LINK_FILES            1001
#define IDC_PAGE_LIST                   1001
#define IDC_PAGE_FRAME                  1002
#define IDC_FILENAME_HELP               1003
#define IDC_NAMING_TEMPLATE_COMBO       1004
#define IDC_OUTPUT_EXISTS_PICTURE       1004
#define IDC_BEHAVIOR_PICTURE            1004
#define IDC_ERROR_BEHAVIOR_PICTURE      1005
#define IDC_PROCESSING_OTHER_PICTURE    1006
#define IDC_APL_FILENAME_TEMPLATE_COMBO 1008
#define IDC_APL_FILENAME_TEMPLATE_HELP  1009
#define IDC_OUTPUT_LOCATION_PICTURE     1010
#define IDC_OUTPUT_LOCATION_SAME_DIRECTORY 1011
#define IDC_OUTPUT_LOCATION_SPECIFIED_DIRECTORY 1012
#define IDC_OUTPUT_LOCATION_DIRECTORY_COMBO 1013
#define IDC_OUTPUT_LOCATION_DIRECTORY_BROWSE 1014
#define IDC_OUTPUT_LOCATION_RECREATE_DIRECTORY_STRUCTURE_CHECK 1015
#define IDC_OUTPUT_LOCATION_RECREATE_DIRECTORY_STRUCTURE_LEVELS_EDIT 1016
#define IDC_OUTPUT_LOCATION_DIRECTORY_COMBO2 1017
#define IDC_OUTPUT_LOCATION_DIRECTORY_RECREATE 1017
#define IDC_SIMULTANEOUS_FILES_COMBO    1018
#define IDC_SIMULTANEOUS_FILES_PICTURE  1019
#define IDC_GENERAL_PICTURE             1019
#define IDC_STOP_ON_ERROR_CHECK         1020
#define IDC_VERIFY_PICTURE              1021
#define IDC_COMPLETION_SOUND_PICTURE    1022
#define IDC_OUTPUT_LOCATION_RECREATE_DIRECTORY_STRUCTURE_STATIC 1022
#define IDC_COMPLETION_SOUND_CHECK      1023
#define IDC_PRIORITY_PICTURE            1024
#define IDC_PRIORITY_COMBO              1025
#define IDC_VERIFY_MODE_COMBO           1026
#define IDC_SHOW_EXTERNAL_WINDOWS       1027
#define IDC_MIRROR_TIME_STAMP_CHECK     1028
#define IDC_COMPLETION_SOUND_CHECK2     1029
#define IDC_AUTO_VERIFY_CHECK           1029
#define IDC_OTHER_PICTURE               1030
#define IDC_OUTPUT_EXISTS_COMBO         1032
#define IDC_DELETE_AFTER_SUCCESS_COMBO  1033
#define IDC_CONFIGURE_EDIT_1            1035
#define IDC_CONFIGURE_STATIC_1          1036
#define IDC_CONFIGURE_EDIT_2            1037
#define IDC_URL                         1037
#define IDC_CONFIGURE_STATIC_2          1038
#define IDC_DESCRIPTION_1               1038
#define IDC_CONFIGURE_EDIT_3            1039
#define IDC_DESCRIPTION_2               1039
#define IDC_CONFIGURE_STATIC_3          1040
#define IDC_TAG_LIST                    1040
#define IDC_FILE_LIST                   1041
#define IDC_TEXT_PLACE_HOLDER           1042
#define IDC_FILES_SELECT_ALL            1044
#define IDC_FILES_SELECT_NONE           1045
#define IDC_TABS                        1046
#define IDC_RICHEDIT21                  1048
#define IDC_FORMAT                      1049
#define IDC_DIVIDER2                    1053
#define IDC_DIVIDER1                    1054
#define IDC_DIVIDER3                    1059
#define IDC_DIVIDER4                    1060
#define IDC_TITLE1                      1061
#define IDC_TITLE2                      1062
#define IDC_TITLE3                      1063
#define IDC_TITLE4                      1064
#define IDC_STATIC1                     1065
#define IDC_STATIC2                     1066
#define IDC_STATIC3                     1067
#define IDC_STATICB1                    1068
#define IDC_STATICB2                    1069
#define IDC_STATICO1                    1070
#define ID_SETTINGS_CUSTOMIZE_TOOLBAR   32771
#define ID_FILE_ADD_FILES               32772
#define ID_FILE_PROCESS_FILES           32773
#define ID_FILE_ADD_FOLDER              32774
#define ID_FILE_REMOVE_FILES            32775
#define ID_FILE_CLEAR_FILES             32776
#define ID_FILE_FILE_INFO               32777
#define ID_TOOLS_OPTIONS                32778
#define ID_FILE_COPY_FILE_LIST          32779
#define ID_FILE_EXIT                    32780
#define ID_TOOLS_MAKE_APL               32781
#define ID_MODE_VERIFY                  32782
#define ID_COMPRESSION_APE_FAST         32783
#define ID_COMPRESSION_APE_NORMAL       32784
#define ID_MODE_COMPRESS                32785
#define ID_MODE_DECOMPRESS              32786
#define ID_COMPRESSION_APE_HIGH         32787
#define ID_COMPRESSION_APE_EXTRA_HIGH   32788
#define ID_COMPRESSION                  32789
#define ID_STOP_IMMEDIATELY             32790
#define ID_STOP_AFTER_CURRENT_FILE      32791
#define ID_PAUSE                        32792
#define ID_STOP                         32793
#define ID_HELP_WEBSITE_MONKEYS_AUDIO   32795
#define ID_HELP_WEBSITE_FORUM           32796
#define ID_HELP_WEBSITE_MEDIA_JUKEBOX   32797
#define ID_HELP_WEBSITE_WINAMP          32798
#define ID_HELP_WEBSITE_EAC             32799
#define ID_COMPRESSION_APE_INSANE       32800
#define ID_HELP_ABOUT                   32801
#define ID_MODE_MAKE_APL                32802
#define ID_COMPRESSION_EXTERNAL_NA      32803
#define ID_COMPRESSION_NA               32804
#define ID_MODE_CONVERT                 32805
#define ID_HELP_HELP                    32806
#define ID_FILE_SELECTALL               32807
#define ID_SELECTALL_CTRL               32808
#define ID_HELP_LICENSE                 32809

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        163
#define _APS_NEXT_COMMAND_VALUE         32810
#define _APS_NEXT_CONTROL_VALUE         1071
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> mac-11.62.zip: Source/MAC/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by MAC.rc
//
#define _USING_V110_SDK71_              1
#define IDC_SYSTEM_INFO                 2
#define IDD_MAC_DIALOG                  102
#define IDD_MAKEAPL_DIALOG              103
#define IDR_MAINFRAME                   128
#define IDR_MAIN_MENU                   128
#define IDB_TREE_ICONS                  143
#define IDB_TOOLBAR_FULL                145
#define IDR_STOP_MENU                   145
#define IDD_OPTIONS                     146
#define IDB_TOOLBAR_SMALL               147
#define IDB_MONKEY_WATERMARK            148
#define IDB_OPTIONS_ICONS               149
#define IDD_OPTIONS_OUTPUT              149
#define IDD_OPTIONS_PROCESSING          151
#define IDR_COMPLETION_WAVE             152
#define IDD_FORMAT_PLUGIN_CONFIGURE     154
#define IDD_FORMAT_PLUGIN_INFO          155
#define IDD_APE_INFO                    159
#define IDD_ABOUT                       160
#define IDD_APE_INFO_FORMAT             161
#define IDC_LIST                        1000
#define IDC_BUILD_LINK_FILES            1001
#define IDC_PAGE_LIST                   1001
#define IDC_PAGE_FRAME                  1002
#define IDC_FILENAME_HELP               1003
#define IDC_NAMING_TEMPLATE_COMBO       1004
#define IDC_OUTPUT_EXISTS_PICTURE       1004
#define IDC_BEHAVIOR_PICTURE            1004
#define IDC_ERROR_BEHAVIOR_PICTURE      1005
#define IDC_PROCESSING_OTHER_PICTURE    1006
#define IDC_APL_FILENAME_TEMPLATE_COMBO 1008
#define IDC_APL_FILENAME_TEMPLATE_HELP  1009
#define IDC_OUTPUT_LOCATION_PICTURE     1010
#define IDC_OUTPUT_LOCATION_SAME_DIRECTORY 1011
#define IDC_OUTPUT_LOCATION_SPECIFIED_DIRECTORY 1012
#define IDC_OUTPUT_LOCATION_DIRECTORY_COMBO 1013
#define IDC_OUTPUT_LOCATION_DIRECTORY_BROWSE 1014
#define IDC_OUTPUT_LOCATION_RECREATE_DIRECTORY_STRUCTURE_CHECK 1015
#define IDC_OUTPUT_LOCATION_RECREATE_DIRECTORY_STRUCTURE_LEVELS_EDIT 1016
#define IDC_OUTPUT_LOCATION_DIRECTORY_COMBO2 1017
#define IDC_OUTPUT_LOCATION_DIRECTORY_RECREATE 1017
#define IDC_SIMULTANEOUS_FILES_COMBO    1018
#define IDC_SIMULTANEOUS_FILES_PICTURE  1019
#define IDC_GENERAL_PICTURE             1019
#define IDC_STOP_ON_ERROR_CHECK         1020
#define IDC_VERIFY_PICTURE              1021
#define IDC_COMPLETION_SOUND_PICTURE    1022
#define IDC_OUTPUT_LOCATION_RECREATE_DIRECTORY_STRUCTURE_STATIC 1022
#define IDC_COMPLETION_SOUND_CHECK      1023
#define IDC_PRIORITY_PICTURE            1024
#define IDC_PRIORITY_COMBO              1025
#define IDC_VERIFY_MODE_COMBO           1026
#define IDC_SHOW_EXTERNAL_WINDOWS       1027
#define IDC_MIRROR_TIME_STAMP_CHECK     1028
#define IDC_COMPLETION_SOUND_CHECK2     1029
#define IDC_AUTO_VERIFY_CHECK           1029
#define IDC_OTHER_PICTURE               1030
#define IDC_OUTPUT_EXISTS_COMBO         1032
#define IDC_DELETE_AFTER_SUCCESS_COMBO  1033
#define IDC_CONFIGURE_EDIT_1            1035
#define IDC_CONFIGURE_STATIC_1          1036
#define IDC_CONFIGURE_EDIT_2            1037
#define IDC_URL                         1037
#define IDC_CONFIGURE_STATIC_2          1038
#define IDC_DESCRIPTION_1               1038
#define IDC_CONFIGURE_EDIT_3            1039
#define IDC_DESCRIPTION_2               1039
#define IDC_CONFIGURE_STATIC_3          1040
#define IDC_TAG_LIST                    1040
#define IDC_FILE_LIST                   1041
#define IDC_TEXT_PLACE_HOLDER           1042
#define IDC_FILES_SELECT_ALL            1044
#define IDC_FILES_SELECT_NONE           1045
#define IDC_TABS                        1046
#define IDC_RICHEDIT21                  1048
#define IDC_FORMAT                      1049
#define IDC_DIVIDER2                    1053
#define IDC_DIVIDER1                    1054
#define IDC_DIVIDER3                    1059
#define IDC_DIVIDER4                    1060
#define IDC_TITLE1                      1061
#define IDC_TITLE2                      1062
#define IDC_TITLE3                      1063
#define IDC_TITLE4                      1064
#define IDC_STATIC1                     1065
#define IDC_STATIC2                     1066
#define IDC_STATIC3                     1067
#define IDC_STATICB1                    1068
#define IDC_STATICB2                    1069
#define IDC_STATICO1                    1070
#define IDC_TITLES                      1071
#define IDC_TITLE5                      1072
#define IDC_DIVIDER5	                1073
#define IDC_SIZE_PICTURE                1074
#define IDC_STATIC4                     1075
#define IDC_PROGRAM_SIZE_COMBO          1076
#define IDC_FONT_SIZE_COMBO             1077
#define IDC_STATIC5                     1078


#define ID_SETTINGS_CUSTOMIZE_TOOLBAR   32771
#define ID_FILE_ADD_FILES               32772
#define ID_FILE_PROCESS_FILES           32773
#define ID_FILE_ADD_FOLDER              32774
#define ID_FILE_REMOVE_FILES            32775
#define ID_FILE_CLEAR_FILES             32776
#define ID_FILE_FILE_INFO               32777
#define ID_TOOLS_OPTIONS                32778
#define ID_FILE_COPY_FILE_LIST          32779
#define ID_FILE_EXIT                    32780
#define ID_TOOLS_MAKE_APL               32781
#define ID_MODE_VERIFY                  32782
#define ID_COMPRESSION_APE_FAST         32783
#define ID_COMPRESSION_APE_NORMAL       32784
#define ID_MODE_COMPRESS                32785
#define ID_MODE_DECOMPRESS              32786
#define ID_COMPRESSION_APE_HIGH         32787
#define ID_COMPRESSION_APE_EXTRA_HIGH   32788
#define ID_COMPRESSION                  32789
#define ID_STOP_IMMEDIATELY             32790
#define ID_STOP_AFTER_CURRENT_FILE      32791
#define ID_PAUSE                        32792
#define ID_STOP                         32793
#define ID_HELP_WEBSITE_MONKEYS_AUDIO   32795
#define ID_HELP_WEBSITE_FORUM           32796
#define ID_HELP_WEBSITE_MEDIA_JUKEBOX   32797
#define ID_HELP_WEBSITE_WINAMP          32798
#define ID_HELP_WEBSITE_EAC             32799
#define ID_COMPRESSION_APE_INSANE       32800
#define ID_HELP_ABOUT                   32801
#define ID_MODE_MAKE_APL                32802
#define ID_COMPRESSION_EXTERNAL_NA      32803
#define ID_COMPRESSION_NA               32804
#define ID_MODE_CONVERT                 32805
#define ID_HELP_HELP                    32806
#define ID_FILE_SELECTALL               32807
#define ID_SELECTALL_CTRL               32808
#define ID_HELP_LICENSE                 32809

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        163
#define _APS_NEXT_COMMAND_VALUE         32810
#define _APS_NEXT_CONTROL_VALUE         1071
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
